import { useState, useEffect } from "react"
import { useHistory } from "react-router-dom";
import { WrapStyle } from './style';
import Store from '../../store'
import avatar from '../../assets/avatar.png';
import logo from '../../assets/logo.png';
import { LogoutOutlined, ExclamationCircleOutlined } from "@ant-design/icons";
import dayjs from 'dayjs';
import { Button, message, Card, Row, Col, Input, InputNumber, Modal, Form, Select } from "antd";
import fetchAxios from '@/api/axios';


const CreateRoomForm = ({ visible, onCreate, onCancel }) => {
	const [form] = Form.useForm();
	return (
		<Modal
			visible={visible}
			title="创建房间"
			okText="立即召开"
			cancelText="取消"
			onCancel={() => {
				form.resetFields();
				onCancel()
			}}
			onOk={() => {
				form
					.validateFields()
					.then((values) => {
						form.resetFields();
						onCreate(values);
					})
					.catch((info) => {
						console.log('校验失败:', info);
					});
			}}
		>
			<Form
				form={form}
				labelCol={{ span: 5 }}
				name="form_in_modal"
				initialValues={{
					duration: 240,
					bitrate: 1024,
					room_type: 2,
					resolution: 12,
					format: 3,
					frame: 30,
				}}
			>
				<Form.Item
					name="room_name"
					label="房间名称"
					rules={[
						{
							required: true,
							message: '请输入房间名称',
						},
					]}
				>
					<Input />
				</Form.Item>
				<Form.Item name="duration" label="房间时长">
					<Form.Item name="duration" noStyle><InputNumber min={0} /></Form.Item>
					<span style={{ marginLeft: 5 }}>分钟 <span>(0为永久房间)</span></span>
				</Form.Item>
				<Form.Item
					name="bitrate"
					label="房间码率"
					rules={[
						{
							required: true,
							message: '请输入房间码率',
						},
					]}>
					<InputNumber min={0} />
				</Form.Item>
				<Form.Item name="room_type" label="会议类型">
					<Select>
						<Select.Option value={0}>传统混合</Select.Option>
						<Select.Option value={1}>端口混合</Select.Option>
						<Select.Option value={2}>SFU纯转发会议</Select.Option>
					</Select>
				</Form.Item>
				<Form.Item
					name="resolution"
					label="房间分辨率"
					rules={[
						{
							required: true,
							message: '请选择房间分辨率',
						},
					]}>
					<Select>
						<Select.Option value={1}>QCIF</Select.Option>
						<Select.Option value={2}>CIF</Select.Option>
						<Select.Option value={3}>4CIF</Select.Option>
						<Select.Option value={12}>720P</Select.Option>
						<Select.Option value={13}>1080P</Select.Option>
						<Select.Option value={14}>WCIF</Select.Option>
						<Select.Option value={15}>W4CIF</Select.Option>
						<Select.Option value={16}>4k</Select.Option>
					</Select>
				</Form.Item>
				<Form.Item
					name="format"
					label="主视频格式"
					rules={[
						{
							required: true,
							message: '请选择主视频格式',
						},
					]}>
					<Select>
						<Select.Option value={1}>MPEG</Select.Option>
						<Select.Option value={2}>H.261</Select.Option>
						<Select.Option value={3}>H.263</Select.Option>
						<Select.Option value={4}>H.264_HP</Select.Option>
						<Select.Option value={5}>H.264_BP</Select.Option>
						<Select.Option value={6}>H.265</Select.Option>
						<Select.Option value={7}>H.263+</Select.Option>
					</Select>
				</Form.Item>
				<Form.Item
					name="frame"
					label="帧率"
					rules={[
						{
							required: true,
							message: '请输入帧率',
						},
					]}>
					<InputNumber min={1} />
				</Form.Item>
			</Form>
		</Modal>
	);
};


export default function List() {
	const history = useHistory();
	const errorCode = "10002"
	useEffect(() => {
		if(window.krtcClient){
			const isLogin = JSON.parse(window.atob(JSON.parse(localStorage.getItem(window.krtcClient && window.krtcClient._singleSdk.getClientId()))["kAuthorization"]))["ssoToken"] || null;
			if (!Store.user || !isLogin) {
				history.push("/login");
			}
		}else{
			history.push("/login");
		}
	}, [])

	const [list, setList] = useState([])
	const [screenList, setScreenList] = useState([])
	const [searchVal, setSearchVal] = useState('')
	const [visible, setVisible] = useState(false);
	const [refresh, setRefresh] = useState({})
	const [modelVisible, setModelVisible] = useState(false)

	useEffect(() => {
		fetchAxios({
			url: '/krtc/rooms',
			method: 'get',
			params: {
				account_token: Store.accountToken,
				count: 0
			}
		}).then(res => {
			if (res.data && res.data.success) {
				setList(res.data.confs)
			} else if (res.data && res.data.error_code == errorCode) {
				setModelVisible(true);
			} else{
				message.error(`列表获取失败`);
			}
		})
	}, [refresh])

	useEffect(() => {
		const _list = list.filter(x => x.room_name.includes(searchVal))
		setScreenList(_list)
	}, [list, searchVal])


	const onSearch = (val) => {
		setSearchVal(val)
	}

	const onCreate = async (val) => {
		setVisible(false)
		const res = await fetchAxios({
			url: `/krtc/rooms`,
			method: 'post',
			_contentType: 'json',
			params: {
				account_token: Store.accountToken,
			},
			data: val
		})
		if(res.data && res.data.success){
			history.push(`/list/${res.data.room_id}`)
		}  else if (res.data && res.data.error_code == errorCode) {
			setModelVisible(true);
		}else {
			message.error(`创建失败`);
		}
	 }

	const handleGo = (x) => () => {
		history.push(`/list/${x.room_id}`)
	}

	const handleDelete = (x) => async () => {
		Modal.confirm({
			title: "确定要删除这个房间吗？",
			icon: <ExclamationCircleOutlined />,
			content: "",
			centered: true,
			okText: "确定",
			okType: "danger",
			cancelText: "取消",
			onOk: async () => {
				const res = await fetchAxios({
					url: `/krtc/rooms/${x.room_id}`,
					method: 'delete',
					params: {
						account_token: Store.accountToken,
					}
				})
				if(res.data && res.data.success){
					message.error(`删除成功`);
					setRefresh({})
				} else if (res.data && res.data.error_code == errorCode) {
					setModelVisible(true);
				}else {
					message.error(`删除失败，只能删除自己创建的房间`);
				}
			},
		});
	}
	const goBackTOLogin = ()=>{
		window.krtcClient && window.krtcClient.destroy()
		window.krtcClient = null
		history.push("/login")
	}
	return <WrapStyle>
		<header>
			<div className="header-left">
				<img src={logo} alt="kedacom" />
				<b style={{ display: "none" }}>科达KRTC音视频通讯示例</b>
			</div>
			<div className="header-right">
				<div className="user">
					<img src={avatar} alt="avatar" />
					<span>{Store.user?.username || ''}</span>
				</div>
				<LogoutOutlined className="logout" onClick={goBackTOLogin} />
			</div>
		</header>
		<main>
			<Row style={{ height: "60px", padding: "15px 10px", marginBottom: "20px", background: "rgb(255, 255, 255)"}}>
				<Col xs={12} sm={12} md={8} lg={9} xl={9} xxl={10}>
					<div style={{ fontSize: "14px", height: "32px", lineHeight: "32px" }}>正在召开的房间（{list.length}）</div>
				</Col>
				<Col xs={0} sm={0} md={8} lg={6} xl={6} xxl={4}>
					<Input.Search placeholder="请输入搜索内容" allowClear enterButton="搜索" onSearch={onSearch} />
				</Col>
				<Col xs={12} sm={12} md={8} lg={9} xl={9} xxl={10}>
					<div style={{ float: "right" }}>
						<Button type="primary" onClick={() => setVisible(true)}>创建房间</Button>
					</div>
				</Col>
			</Row>

			<section className="rooms">
				<Row gutter={16}>
					{
						screenList.map(x => (
							<Col sm={24} md={12} lg={8} xl={6} xxl={4} key={x.room_id}>
								<Card
									title={x.room_name}
									className="room-card"
									actions={[
										<div onClick={handleGo(x)}>进入房间</div>,
										<div onClick={handleDelete(x)}>删除房间</div>,
									]}
								>
									<div className="room-card-item">房间号：{x.room_id}</div>
									<div className="room-card-item">创建者：{x.creator}</div>
									<div className="room-card-item">开始时间：{dayjs(x.start_time).format('YYYY-MM-DD HH:mm:ss')}</div>
								</Card>
							</Col>
						))
					}
				</Row>
			</section>
		</main>
		<CreateRoomForm visible={visible} onCreate={onCreate} />
		<Modal visible={modelVisible} onOk={()=>{history.push("/login")}} closable={false} footer={[
            <Button  onClick={goBackTOLogin}>
              确定
            </Button>
          ]}>
			<p>token失效</p>
		</Modal>
	</WrapStyle>
}
