import React, {  useEffect, useRef } from 'react'

import { Button } from 'antd'

import classnames from 'classnames'


const PreeView = props => {
	const { mediatType,krtcClient, track, peerInfo, isMe = false, style, onPeerClick = () => {}, toBigView = false } = props

	const videRef = useRef()

	const _setTracks = _track => {
		const videoElem = videRef.current
		if (!videoElem) {
			return false
		}
		if (_track) {
			const stream = new MediaStream()
			stream.addTrack(_track)
			videoElem.srcObject = stream
			videoElem.play().catch(error => console.log('videoElem.play() failed:%o', error))
		} else {
			videoElem.srcObject = null
		}
	}

	useEffect(() => {
		_setTracks(track)
	}, [track])
	//订阅流
	const subscribeStream = (peerInfo,mediatType)=>{
		krtcClient.subscribe({
			userId: peerInfo.e164,
			mediaType: mediatType,
			quality: 'low',
			error: (err) => {
				console.log("------开启订阅失败-------",err)
			}
		})
	}
	//取消订阅
	const unSubscribeStream = (peerInfo,mediatType)=>{
		krtcClient.unsubscribe({
			userId: peerInfo.e164,
			mediaType: mediatType,
			quality: 'low',
			error: (err) => {
				console.log("-------取消订阅失败------",err)
			}
		})
	}
	return (
		<div
			className={classnames('member_each', {
				member_each_first: toBigView
			})}
			style={style}
			onClick={() => {
				onPeerClick && onPeerClick(peerInfo)
			}}
			key={peerInfo.e164}
		>
			<video playsInline autoPlay ref={videRef} id={'member_each_video_' + peerInfo.e164} />
			<div className="member_each_tool">
				<div className="member_each_tool_left">
					{peerInfo.alias || peerInfo.displayName}
					{isMe ? '-自己' : ''}
				</div>
				<div className="member_each_tool_right">
					{!isMe && (
						<Button
							size="small"
							onClick={e => {
								e.nativeEvent.stopImmediatePropagation()
								e.stopPropagation()
								if (track) {
									unSubscribeStream(peerInfo,mediatType)
								} else {
									subscribeStream(peerInfo,mediatType)
								}
							}}
						>
							{track ? '取消订阅' : '订阅视频'}
						</Button>
					)}
				</div>
			</div>
		</div>
	)
}

export default PreeView
